@@ -1,25 +1,25 @@
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import configargparse
 import ct.apptools
 import psutil
 
+
 def _cpus():
     thisprocess = psutil.Process()
     return len(thisprocess.cpu_affinity())
 
+
 def add_arguments(cap):
     cap.add(
         "-j",
         "--jobs",
         "--CAKE_PARALLEL",
         "--parallel",
-        dest='parallel',
+        dest="parallel",
         type=int,
         default=_cpus(),
-        help="Sets the number of CPUs to use in parallel for a build.")
-        
+        help="Sets the number of CPUs to use in parallel for a build.",
+    )
+
 
 def main(argv=None):
     cap = configargparse.getArgumentParser()
