@@ -6,11 +6,13 @@ import ct.utils
 import ct.apptools
 import ct.configutils
 
+
 class Namer(object):
 
     """ From a source filename, calculate related names
         like executable name, object name, etc.
     """
+
     def __init__(self, args, argv=None, variant=None, exedir=None):
         self.args = args
         self._project = ct.git_utils.Project(args)
@@ -19,9 +21,9 @@ class Namer(object):
     def add_arguments(cap, argv=None, variant=None):
         ct.apptools.add_common_arguments(cap, argv=argv, variant=variant)
         if variant is None:
-            variant = 'unsupplied'
+            variant = "unsupplied"
         ct.apptools.add_output_directory_arguments(cap, variant=variant)
-    
+
     def topbindir(self):
         """ What is the topmost part of the bin directory """
         if "bin" in self.args.bindir:
@@ -35,9 +37,7 @@ class Namer(object):
         """
         if sourcefilename:
             project_pathname = self._project.pathname(sourcefilename)
-            relative = os.path.join(
-                defaultdir,
-                ct.wrappedos.dirname(project_pathname))
+            relative = os.path.join(defaultdir, ct.wrappedos.dirname(project_pathname))
         else:
             relative = defaultdir
         return ct.wrappedos.realpath(relative)
@@ -56,14 +56,15 @@ class Namer(object):
         """ Return the name (not the path) of the object file
             for the given source.
         """
-        directory,name = os.path.split(sourcefilename)
+        directory, name = os.path.split(sourcefilename)
         basename = os.path.splitext(name)[0]
-        return "".join([directory.replace('/','@@'),'@@',basename, ".o"])
+        return "".join([directory.replace("/", "@@"), "@@", basename, ".o"])
 
     @memoize
     def object_pathname(self, sourcefilename):
-        return "".join([self.object_dir(sourcefilename),
-                        "/", self.object_name(sourcefilename)])
+        return "".join(
+            [self.object_dir(sourcefilename), "/", self.object_name(sourcefilename)]
+        )
 
     @memoize
     def executable_dir(self, sourcefilename=None):
@@ -79,9 +80,13 @@ class Namer(object):
 
     @memoize
     def executable_pathname(self, sourcefilename):
-        return "".join([self.executable_dir(sourcefilename),
-                        "/",
-                        self.executable_name(sourcefilename)])
+        return "".join(
+            [
+                self.executable_dir(sourcefilename),
+                "/",
+                self.executable_name(sourcefilename),
+            ]
+        )
 
     @memoize
     def staticlibrary_name(self, sourcefilename=None):
@@ -95,9 +100,13 @@ class Namer(object):
         """ Put static libraries in the same directory as executables """
         if sourcefilename is None and self.args.static:
             sourcefilename = ct.wrappedos.realpath(self.args.static[0])
-        return "".join([self.executable_dir(sourcefilename),
-                        "/",
-                        self.staticlibrary_name(sourcefilename)])
+        return "".join(
+            [
+                self.executable_dir(sourcefilename),
+                "/",
+                self.staticlibrary_name(sourcefilename),
+            ]
+        )
 
     @memoize
     def dynamiclibrary_name(self, sourcefilename=None):
@@ -111,28 +120,36 @@ class Namer(object):
         """ Put dynamic libraries in the same directory as executables """
         if sourcefilename is None and self.args.dynamic:
             sourcefilename = ct.wrappedos.realpath(self.args.dynamic[0])
-        return "".join([self.executable_dir(sourcefilename),
-                        "/",
-                        self.dynamiclibrary_name(sourcefilename)])
+        return "".join(
+            [
+                self.executable_dir(sourcefilename),
+                "/",
+                self.dynamiclibrary_name(sourcefilename),
+            ]
+        )
 
     def all_executable_pathnames(self):
         """ Use the filenames from the command line to determine the 
             executable names.
         """
-        allexes = set()
+        allexes = ct.utils.OrderedSet()
         if self.args.filename:
-            allexes = { self.executable_pathname(ct.wrappedos.realpath(source)) 
-                            for source in self.args.filename}
+            allexes = {
+                self.executable_pathname(ct.wrappedos.realpath(source))
+                for source in self.args.filename
+            }
         return allexes
 
     def all_test_pathnames(self):
         """ Use the test files from the command line to determine the 
             executable names.
         """
-        alltests = set() 
+        alltests = ct.utils.OrderedSet()
         if self.args.tests:
-            alltestsexes = { self.executable_pathname(ct.wrappedos.realpath(source)) 
-                                for source in self.args.tests}
+            alltestsexes = {
+                self.executable_pathname(ct.wrappedos.realpath(source))
+                for source in self.args.tests
+            }
         return alltests
 
     def clear_cache(self):
@@ -149,4 +166,3 @@ class Namer(object):
         self.staticlibrary_pathname.cache.clear()
         self.dynamiclibrary_name.cache.clear()
         self.dynamiclibrary_pathname.cache.clear()
-
