@@ -1,6 +1,3 @@
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import os
 import unittest
 import shutil
@@ -21,11 +18,12 @@ import ct.headerdeps
 import ct.magicflags
 from ct.utils import OrderedSet
 
+
 def _reload_ct(cache_home):
     """ Set the CTCACHE environment variable to cache_home
         and reload the ct.* modules
     """
-    os.environ['CTCACHE'] = cache_home
+    os.environ["CTCACHE"] = cache_home
     reload(ct.dirnamer)
     reload(ct.apptools)
     reload(ct.headerdeps)
@@ -33,23 +31,25 @@ def _reload_ct(cache_home):
 
 
 class TestMagicFlagsModule(unittest.TestCase):
-
     def setUp(self):
         uth.reset()
 
-    def _createmagicparser(self, extraargs=None, cache_home='None', tempdir=None):
+    def _createmagicparser(self, extraargs=None, cache_home="None", tempdir=None):
         if not extraargs:
             extraargs = []
         temp_config_name = ct.unittesthelper.create_temp_config(tempdir)
-        argv = ['--config='+temp_config_name] + extraargs
+        argv = ["--config=" + temp_config_name] + extraargs
         _reload_ct(cache_home)
-        config_files = ct.configutils.config_files_from_variant(argv=argv,exedir=uth.cakedir())
+        config_files = ct.configutils.config_files_from_variant(
+            argv=argv, exedir=uth.cakedir()
+        )
         cap = configargparse.getArgumentParser(
-            description='TestMagicFlagsModule',
+            description="TestMagicFlagsModule",
             formatter_class=configargparse.ArgumentDefaultsHelpFormatter,
             default_config_files=config_files,
-            args_for_setting_config_path=["-c","--config"],
-            ignore_unknown_config_file_keys=True)
+            args_for_setting_config_path=["-c", "--config"],
+            ignore_unknown_config_file_keys=True,
+        )
         ct.apptools.add_common_arguments(cap)
         ct.dirnamer.add_arguments(cap)
         ct.headerdeps.add_arguments(cap)
@@ -63,14 +63,14 @@ class TestMagicFlagsModule(unittest.TestCase):
         tempdir = tempfile.mkdtemp()
         os.chdir(tempdir)
 
-        relativepath = 'simple/test_cflags.c'
+        relativepath = "simple/test_cflags.c"
         samplesdir = uth.samplesdir()
         realpath = os.path.join(samplesdir, relativepath)
         magicparser = self._createmagicparser(tempdir=tempdir)
         # magicparser._headerdeps.process(realpath)
         self.assertSetEqual(
-            set(magicparser.parse(realpath).get('CFLAGS')),
-            set(['-std=gnu99']))
+            set(magicparser.parse(realpath).get("CFLAGS")), set(["-std=gnu99"])
+        )
 
         os.chdir(origdir)
         shutil.rmtree(tempdir, ignore_errors=True)
@@ -80,15 +80,18 @@ class TestMagicFlagsModule(unittest.TestCase):
         tempdir = tempfile.mkdtemp()
         os.chdir(tempdir)
 
-        relativepath = 'cross_platform/cross_platform.cpp'
+        relativepath = "cross_platform/cross_platform.cpp"
         samplesdir = uth.samplesdir()
         realpath = os.path.join(samplesdir, relativepath)
-        magicparser = self._createmagicparser(['--magic', 'direct'],tempdir=tempdir)
+        magicparser = self._createmagicparser(["--magic", "direct"], tempdir=tempdir)
         # magicparser._headerdeps.process(realpath)
         self.assertSetEqual(
-            set(magicparser.parse(realpath).get('SOURCE')),
-            {os.path.join(samplesdir,'cross_platform/cross_platform_lin.cpp'), 
-             os.path.join(samplesdir,'cross_platform/cross_platform_win.cpp')})
+            set(magicparser.parse(realpath).get("SOURCE")),
+            {
+                os.path.join(samplesdir, "cross_platform/cross_platform_lin.cpp"),
+                os.path.join(samplesdir, "cross_platform/cross_platform_win.cpp"),
+            },
+        )
 
         os.chdir(origdir)
         shutil.rmtree(tempdir, ignore_errors=True)
@@ -98,14 +101,15 @@ class TestMagicFlagsModule(unittest.TestCase):
         tempdir = tempfile.mkdtemp()
         os.chdir(tempdir)
 
-        relativepath = 'cross_platform/cross_platform.cpp'
+        relativepath = "cross_platform/cross_platform.cpp"
         samplesdir = uth.samplesdir()
         realpath = os.path.join(samplesdir, relativepath)
-        magicparser = self._createmagicparser(['--magic', 'cpp'],tempdir=tempdir)
+        magicparser = self._createmagicparser(["--magic", "cpp"], tempdir=tempdir)
         # magicparser._headerdeps.process(realpath)
         self.assertSetEqual(
-            set(magicparser.parse(realpath).get('SOURCE')),
-            {os.path.join(samplesdir,'cross_platform/cross_platform_lin.cpp')})
+            set(magicparser.parse(realpath).get("SOURCE")),
+            {os.path.join(samplesdir, "cross_platform/cross_platform_lin.cpp")},
+        )
 
         os.chdir(origdir)
         shutil.rmtree(tempdir, ignore_errors=True)
@@ -115,17 +119,18 @@ class TestMagicFlagsModule(unittest.TestCase):
         tempdir = tempfile.mkdtemp()
         os.chdir(tempdir)
 
-        relativepath = 'lotsofmagic/lotsofmagic.cpp'
+        relativepath = "lotsofmagic/lotsofmagic.cpp"
         samplesdir = uth.samplesdir()
         realpath = os.path.join(samplesdir, relativepath)
-        magicparser = self._createmagicparser(['--magic', 'cpp'],tempdir=tempdir)
+        magicparser = self._createmagicparser(["--magic", "cpp"], tempdir=tempdir)
 
         expected = {
-            'LDFLAGS': {'-lm'},
-            'F1': {'1'},
-            'LINKFLAGS': {'-lpcap'},
-            'F2': {'2'},
-            'F3': {'3'}}
+            "LDFLAGS": {"-lm"},
+            "F1": {"1"},
+            "LINKFLAGS": {"-lpcap"},
+            "F2": {"2"},
+            "F3": {"3"},
+        }
         self.assertEqual(magicparser.parse(realpath), expected)
 
         os.chdir(origdir)
@@ -136,15 +141,21 @@ class TestMagicFlagsModule(unittest.TestCase):
         tempdir = tempfile.mkdtemp()
         os.chdir(tempdir)
 
-        relativepath = 'magicsourceinheader/main.cpp'
+        relativepath = "magicsourceinheader/main.cpp"
         samplesdir = uth.samplesdir()
         realpath = os.path.join(samplesdir, relativepath)
-        magicparser = self._createmagicparser(['--magic', 'cpp'],tempdir=tempdir)
+        magicparser = self._createmagicparser(["--magic", "cpp"], tempdir=tempdir)
         expected = {
-            'LDFLAGS': OrderedSet(
-                ['-lm']),
-            'SOURCE': OrderedSet(
-                [os.path.join(samplesdir,'magicsourceinheader/include_dir/sub_dir/the_code_lin.cpp')])}
+            "LDFLAGS": OrderedSet(["-lm"]),
+            "SOURCE": OrderedSet(
+                [
+                    os.path.join(
+                        samplesdir,
+                        "magicsourceinheader/include_dir/sub_dir/the_code_lin.cpp",
+                    )
+                ]
+            ),
+        }
         self.assertEqual(magicparser.parse(realpath), expected)
 
         os.chdir(origdir)
